@@ -1,14 +1,13 @@
-#!/usr/local/bin/python3.9
+#!/usr/local/bin/python3.11
 
 from pyUIClass.widg_addPolyOpt import Ui_Form
-import PyQt5.QtWidgets as Qw
-import PyQt5.QtGui as Qg
-import PyQt5.QtCore as Qc
+import PyQt5.QtWidgets as QtWidgets
+import PyQt5.QtGui as QtGui
 
 import sys
 
 
-class Widg_addPolyOpt(Qw.QWidget):
+class Widg_addPolyOpt(QtWidgets.QWidget):
     def __init__(self, info):
         super().__init__()
         self.ui = Ui_Form()
@@ -18,7 +17,7 @@ class Widg_addPolyOpt(Qw.QWidget):
 
         self.ui.chkInscribed.setChecked(self.info['inscribed'])
         self.ui.txtSides.setText(str(self.info['sides']))
-        self.ui.txtSides.setValidator(Qg.QIntValidator())
+        self.ui.txtSides.setValidator(QtGui.QIntValidator())
 
         self.ui.chkInscribed.stateChanged.connect(self.chkInscribedUpdate)
         self.ui.txtSides.textChanged.connect(self.txtSidesUpdate)
